@@ -1926,6 +1926,8 @@ enter_nwad(n, sp, ep, s, he)
 	 */
 	    if (!he)
 		break;
+	    if (!he->h_addr_list[ac-1]) /* Check if address list ended prematurely */
+		break;
 	    if (!(ap = (unsigned char *)he->h_addr_list[ac++]))
 		break;
 
@@ -1964,7 +1966,6 @@ enter_state_spec(ss)
 {
 	char *cp, *ne, *ns, *pr;
 	int err, d, f, i, tx, x;
-	size_t len;
 	static char *ssc = (char *)NULL;
 	char *ty;
 /*
@@ -2471,7 +2472,7 @@ lkup_hostnm(hn, n)
 	he = gethostbyname(hn);
 #endif	/* defined(HASIPv6) */
 
-	if (!he)
+	if (!he || !he->h_addr)
 	    return(he);
 /*
  * Copy first hostname structure address to destination structure.
