@@ -339,12 +339,12 @@ gather_proc_info()
 		continue;
 	    uid = (UID_ARG)sb.st_uid;
 	    ht = pidts = 0;
-	/*
-	 * Get the PID's command name.
-	 */
+	    /*
+	     * Get the PID's command name.
+	     */
 	    (void) make_proc_path(pidpath, n, &path, &pathl, "stat");
 	    if ((prv = read_id_stat(path, pid, &cmd, &ppid, &pgid)) < 0)
-		cmd = "(unknown)";
+		cmd = NULL; /* NULL means failure to get command name */
 
 #if	defined(HASTASKS)
 	/*
@@ -356,11 +356,16 @@ gather_proc_info()
 	 * options work properly.
 	 */
 	    else if (!IgnTasks && (Selflags & SELTASK)) {
+		/*
+		 * Copy cmd before next call to read_id_stat due to static
+		 * variables
+		 */
 		if (cmd) {
 		    strncpy(cmdbuf, cmd, sizeof(cmdbuf) - 1);
+		    cmdbuf[sizeof(cmdbuf) - 1] = '\0';
+		    cmd = cmdbuf;
 		}
-		cmdbuf[sizeof(cmdbuf) - 1] = '\0';
-		cmd = cmdbuf;
+
 		(void) make_proc_path(pidpath, n, &taskpath, &taskpathl,
 				      "task");
 		tx = n + 4;
@@ -573,8 +578,7 @@ get_fdinfo(p, msk, fi)
 			   So even if we found one, we can not exit the loop.
 			   However, we can assume tfd lines are continuous. */
 		     opt_flg != FDINFO_TFD
-		     && (rv == msk || (rv & FDINFO_TFD))
-						    )
+		     && (rv == msk || (rv & FDINFO_TFD)))
 		    || (
 			/* Too many tfds. */
 			opt_flg == FDINFO_TFD
@@ -661,20 +665,20 @@ initialize()
 			    fd);
 		if (!lstat(path, &sb)) {
 		    if (sb.st_size == (off_t)LSTAT_TEST_SEEK)
-			OffType = 1;
+			OffType = OFFSET_LSTAT;
 		}
 	    }
-	    if (!OffType) {
+	    if (OffType == OFFSET_UNKNOWN) {
 		(void) snpf(path, sizeof(path), "%s/%d/fdinfo/%d", PROCFS,
 			    Mypid, fd);
 		if (get_fdinfo(path, FDINFO_POS, &fi) & FDINFO_POS) {
 		    if (fi.pos == (off_t)LSTAT_TEST_SEEK)
-			OffType = 2;
+			OffType = OFFSET_FDINFO;
 		}
 	    }
 	    (void) close(fd);
 	}
-	if (!OffType) {
+	if (OffType == OFFSET_UNKNOWN) {
 	    if (Foffset && !Fwarn)
 		(void) fprintf(stderr,
 		    "%s: WARNING: can't report offset; disregarding -o.\n",
@@ -682,7 +686,7 @@ initialize()
 	    Foffset = 0;
 	    Fsize = 1;
 	}
-	if (Fsv && (OffType != 2)) {
+	if (Fsv && (OffType != OFFSET_FDINFO)) {
 	    if (!Fwarn && FsvByf)
 		(void) fprintf(stderr,
 		    "%s: WARNING: can't report file flags; disregarding +f.\n",
@@ -706,20 +710,19 @@ initialize()
  *	pp = pointer to /proc prefix
  *	lp = length of prefix
  *	np = pointer to malloc'd buffer to receive new file's path
- *	nl = length of new file path buffer
+ *	nl = size of new file path buffer
  *	sf = new path's suffix
  *
  * return: length of new path
  *	np = updated with new path
- *	nl = updated with new path length
+ *	nl = updated with new buffer size
  */
-
 int
 make_proc_path(pp, pl, np, nl, sf)
 	char *pp;			/* path prefix -- e.g., /proc/<pid>/ */
 	int pl;				/* strlen(pp) */
 	char **np;			/* malloc'd receiving buffer */
-	int *nl;			/* strlen(*np) */
+	int *nl;			/* malloc'd size */
 	char *sf;			/* suffix of new path */
 {
 	char *cp;
@@ -832,18 +835,20 @@ nm2id(nm, id, idl)
 	int *id;			/* pointer to ID receiver */
 	int *idl;			/* pointer to ID length receiver */
 {
-	register int tid, tidl;
+	int tid, tidl;
+	int invalid;
 
 	for (*id = *idl = tid = tidl = 0; *nm; nm++) {
 
 #if	defined(__STDC__)	/* { */
-	    if (!isdigit((unsigned char)*nm))
+	    invalid = !isdigit((unsigned char)*nm);
 #else	/* !defined(__STDC__)	   } { */
-	    if (!isascii(*nm) || !isdigit((unsigned char)*cp))
+	    invalid = !isascii(*nm) || !isdigit((unsigned char)*cp);
 #endif	/* defined(__STDC__)	   } */
-		{
-		    return(1);
-		}
+	    if (invalid)
+	    {
+		return(1);
+	    }
 	    tid = tid * 10 + (int)(*nm - '0');
 	    tidl++;
 	}
@@ -1211,7 +1216,7 @@ process_id(idp, idpl, cmd, uid, pid, ppid, pgid, tid, tcmd)
 	if ((i = make_proc_path(idp, idpl, &dpath, &dpathl, "fd/")) < 3)
 	    return(0);
 	dpath[i - 1] = '\0';
-	if ((OffType == 2)
+	if ((OffType == OFFSET_FDINFO)
 	&&  ((j = make_proc_path(idp, idpl, &ipath, &ipathl, "fdinfo/")) >= 7))
 	    oty = 1;
 	else
@@ -1437,10 +1442,9 @@ compare_mntns(pid)
  */
 
 static void
-process_proc_map(p, s, ss)
-	char *p;			/* path to process maps file */
-	struct stat *s;			/* executing text file state buffer */
-	int ss;				/* *s status -- i.e., SB_* values */
+process_proc_map(char *p,			/* path to process maps file */
+	struct stat *s,			/* executing text file state buffer */
+	int ss)				/* *s status -- i.e., SB_* values */
 {
 	char buf[MAXPATHLEN + 1], *ep, fmtbuf[32], **fp, nmabuf[MAXPATHLEN + 1];
 	dev_t dev;
@@ -1706,14 +1710,12 @@ process_proc_map(p, s, ss)
  *          1 == ID is a zombie
  *	    2 == ID is a thread
  */
-
 static int
-read_id_stat(p, id, cmd, ppid, pgid)
-	char *p;			/* path to status file */
-	int id;				/* ID: PID or LWP */
-	char **cmd;			/* malloc'd command name */
-	int *ppid;			/* returned parent PID for PID type */
-	int *pgid;			/* returned process group ID for PID
+read_id_stat(char *p,			/* path to status file */
+	int id,				/* ID: PID or LWP */
+	char **cmd,			/* malloc'd command name */
+	int *ppid,			/* returned parent PID for PID type */
+	int *pgid)			/* returned process group ID for PID
 					 * type */
 {
 	char buf[MAXPATHLEN], *cp, *cp1, **fp;
@@ -1758,14 +1760,22 @@ read_id_stat(p, id, cmd, ppid, pgid)
 	    goto read_id_stat_exit;
 	cp++;
 	pc = 1;			/* start the parenthesis balance count at 1 */
-/*
- * Enter the command characters safely.  Supply them from the initial read
- * of the stat file line, a '\n' if the initial read didn't yield a ')'
- * command closure, or by reading the rest of the command a character at
- * a time from the stat file.  Count embedded '(' characters and balance
- * them with embedded ')' characters.  The opening '(' starts the balance
- * count at one.
- */
+
+	/* empty process name to avoid leaking previous process name,
+	 * see issue #246
+	 */
+	if (cbf) {
+	    cbf[0] = '\0';
+	}
+
+	/*
+	 * Enter the command characters safely.  Supply them from the initial read
+	 * of the stat file line, a '\n' if the initial read didn't yield a ')'
+	 * command closure, or by reading the rest of the command a character at
+	 * a time from the stat file.  Count embedded '(' characters and balance
+	 * them with embedded ')' characters.  The opening '(' starts the balance
+	 * count at one.
+	 */
 	for (cx = es = 0;;) {
 	    if (!es)
 		ch = *cp++;
@@ -1777,10 +1787,10 @@ read_id_stat(p, id, cmd, ppid, pgid)
 		pc++;
 	    if (ch == ')') {
 
-	    /*
-	     * Balance parentheses when a closure is encountered.  When
-	     * they are balanced, this is the end of the command.
-	     */
+		/*
+		 * Balance parentheses when a closure is encountered.  When
+		 * they are balanced, this is the end of the command.
+		 */
 		pc--;
 		if (!pc)
 		    break;
@@ -1794,12 +1804,12 @@ read_id_stat(p, id, cmd, ppid, pgid)
 		es = 1;		/* Switch to fgetc() when a '\0' appears. */
 	}
 	*cmd = cbf;
-/*
- * Read the remainder of the stat line if it was necessary to read command
- * characters individually from the stat file.
- *
- * Separate the reminder into fields.
- */
+	/*
+	 * Read the remainder of the stat line if it was necessary to read command
+	 * characters individually from the stat file.
+	 *
+	 * Separate the reminder into fields.
+	 */
 	if (es)
 	    cp = fgets(buf, sizeof(buf), fs);
 	(void) fclose(fs);
@@ -1842,13 +1852,11 @@ read_id_stat(p, id, cmd, ppid, pgid)
  *	 This function should be used only when links have been successfully
  *	 resolved in the /proc path by getlinksrc().
  */
-
 static int
-statEx(p, s, ss)
-	char *p;			/* file path */
-	struct stat *s;			/* stat() result -- NULL if none
+statEx(char *p,			/* file path */
+	struct stat *s,			/* stat() result -- NULL if none
 					 * wanted */
-	int *ss;			/* stat() status --  SB_* values */
+	int *ss)			/* stat() status --  SB_* values */
 {
 	static size_t ca = 0;
 	static char *cb = NULL;
