@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.29 2006/03/27 22:57:11 abe Exp $
+ * $Id: machine.h,v 1.37 2014/10/13 22:25:58 abe Exp $
  */
 
 
@@ -140,6 +140,13 @@
 /* #define	HASFIFONODE	1 */
 
 
+/*
+ * HASEOPT is defined for dialects that support the -e option
+ */
+
+#define	HASEOPT	1
+
+
 /*
  * HASFSINO is defined for those dialects that have the file system
  * inode element, fs_ino, in the lfile structure definition in lsof.h.
@@ -161,12 +168,12 @@
  *   HASNOFSNADDR -- has no file structure node address
  */
 
-/* #define	HASFSTRUCT	1 */
+#define	HASFSTRUCT	1
 /* #define	FSV_DEFAULT	FSV_? | FSV_? | FSV_? */
-/* #define	HASNOFSADDR	1	has no file structure address */
+#define	HASNOFSADDR	1	/* has no file structure address */
 /* #define	HASNOFSFLAGS	1	has no file structure flags */
-/* #define	HASNOFSCOUNT	1	has no file structure count */
-/* #define	HASNOFSNADDR	1	has no file structure node address */
+#define	HASNOFSCOUNT	1	/* has no file structure count */
+#define	HASNOFSNADDR	1	/* has no file structure node address */
 
 
 /*
@@ -238,6 +245,13 @@
 /* #define SETLFILEADD Lf->... */
 
 
+/*
+ * HASLWP is defined for dialects that have LWP support inside processes.
+ */
+
+#define	HASLWP	1
+
+
 /*
  * HASMNTSTAT indicates the dialect supports the mount stat(2) result option
  * in its l_vfs and mounts structures.
@@ -303,6 +317,13 @@
 /* #define	HASPIPENODE	1 */
 
 
+/*
+ * HASEPTOPTS is defined for dialects that support the +|-E options.
+ */
+
+#define		HASEPTOPTS	1
+
+
 /*
  * HASPMAPENABLED is defined when the reporting of portmapper registration
  * info is enabled by default.
@@ -330,7 +351,6 @@
 /* #define	HASPRINTINO	print_ino?	*/
 /* #define	HASPRINTNM	print_nm?	*/
 /* #define	HASPRINTOFF	print_off?	*/
-/* #define	HASPRINTSZ	print_sz?	*/
 
 
 /*
@@ -481,6 +501,13 @@
 /* #define	HASSTREAMS	1 */
 
 
+/*
+ * HASTASKS is defined for those dialects that have task reporting support.
+ */
+
+#define	HASTASKS	1
+
+
 /*
  * HASTCPTPIQ is defined for dialects where it is possible to report the
  * TCP/TPI Recv-Q and Send-Q values produced by netstat.
@@ -497,6 +524,15 @@
 /* #define	HASTCPTPIW	1 */
 
 
+/*
+ * HASTCPUDPSTATE is defined for dialects that have TCP and UDP state
+ * support -- i.e., for the "-stcp|udp:state" option and its associated
+ * speed improvements.
+ */
+
+#define	HASTCPUDPSTATE	1
+
+
 /*
  * HASTMPNODE is defined for those dialects that have tmpnodes.
  */
@@ -520,7 +556,7 @@
  * option's default binary value -- 0 or 1.
  */
 
-#define	HASXOPT		"skip TCP&UDP files"
+#define	HASXOPT		"skip TCP&UDP* files"
 #define	HASXOPT_VALUE	0
 
 
@@ -558,7 +594,7 @@
 /* #define	USE_LIB_CKKV			1	   ckkv.c */
 /* #define	USE_LIB_COMPLETEVFS		1	   cvfs.c */
 /* #define	USE_LIB_FIND_CH_INO		1	   fino.c */
-#define	USE_LIB_IS_FILE_NAMED			1	/* isfn.c */
+/* #define	USE_LIB_IS_FILE_NAMED		1	   isfn.c */
 /* #define	USE_LIB_LKUPDEV			1	   lkud.c */
 /* #define	USE_LIB_PRINTDEVNAME		1	   pdvn.c */
 /* #define	USE_LIB_PROCESS_FILE		1	   prfp.c */
@@ -609,6 +645,6 @@
  * zeromem is a macro that uses bzero or memset.
  */
 
-#define	zeromem(a, l)	bzero(a, l)
+#define	zeromem(a, l)	memset(a, 0, l)
 
 #endif	/* !defined(LSOF_MACHINE_H) */
