@@ -30,16 +30,10 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(USE_LIB_PROCESS_FILE)
 
-# if	!defined(lint)
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: prfp.c,v 1.12 2006/03/27 22:56:06 abe Exp $";
-# endif	/* !defined(lint) */
-
 #include "../lsof.h"
 
 
@@ -63,6 +57,7 @@ process_file(fp)
 {
 	struct file f;
 	int flag;
+	char tbuf[32];
 
 #if	defined(FILEPTR)
 /*
@@ -142,6 +137,18 @@ process_file(fp)
 		return;
 #endif	/* defined(DTYPE_PIPE) */
 
+#if	defined(DTYPE_PTS)
+	    case DTYPE_PTS:
+# if	defined(HASPTSFN)
+		HASPTSFN((KA_T)f.f_data);
+# endif	/* defined(HASPTSFN) */
+		return;
+#endif	/* defined(DTYPE_PIPE) */
+
+#if	defined(DTYPE_FIFO)
+	    case DTYPE_FIFO:
+#endif	/* defined(DTYPE_FIFO) */
+
 #if	defined(DTYPE_GNODE)
 	    case DTYPE_GNODE:
 #endif	/* defined(DTYPE_GNODE) */
@@ -194,10 +201,22 @@ process_file(fp)
 #endif	/* defined(HASPRIVFILETYPE) */
 
 	    default:
+
+#if	defined(X_BADFILEOPS)
+		if (X_bfopsa && f.f_ops && (X_bfopsa == (KA_T)f.f_ops)) {
+		    (void) snpf(Namech, Namechl,
+			"no more information; ty=%d file may be closing",
+			(int)f.f_type);
+		    enter_nm(Namech);
+		    return;
+		}
+#endif	/* defined(X_BADFILEOPS) */
+
 		if (f.f_type || f.f_ops) {
 		    (void) snpf(Namech, Namechl,
-			"%s file struct, ty=%#x, op=%#x",
-			print_kptr(fp, (char *)NULL, 0), f.f_type, f.f_ops);
+			"%s file struct, ty=%d, op=%s",
+			print_kptr(fp, tbuf, sizeof(tbuf)), (int)f.f_type,
+			print_kptr((KA_T)f.f_ops, (char *)NULL, 0));
 		    enter_nm(Namech);
 		    return;
 		}
@@ -206,5 +225,5 @@ process_file(fp)
 	enter_nm("no more information");
 }
 #else	/* !defined(USE_LIB_PROCESS_FILE) */
-static char d1[] = "d"; static char *d2 = d1;
+char prfp_d1[] = "d"; char *prfp_d2 = prfp_d1;
 #endif	/* defined(USE_LIB_PROCESS_FILE) */
