@@ -30,16 +30,10 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(USE_LIB_READMNT)
 
-# if	!defined(lint)
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: rmnt.c,v 1.12 2008/10/21 16:13:23 abe Exp $";
-# endif	/* !defined(lint) */
-
 #include "../lsof.h"
 
 
@@ -65,7 +59,7 @@ static char *rcsid = "$Id: rmnt.c,v 1.12 2008/10/21 16:13:23 abe Exp $";
  *     containing an integer file system type, and MOUNTS_STAT_FSTYPE to
  *     specify the member name of the integer in the local mounts structure
  *     where RMNT_STAT_FSTYPE is to be copied.
- *     
+ *
  */
 
 #if	!defined(RMNT_EXPDEV)
@@ -103,7 +97,7 @@ readmnt()
  */
 	if (!(mfp = setmntent(MOUNTED, "r"))) {
 	    (void) fprintf(stderr, "%s: can't access %s\n", Pn, MOUNTED);
-	    Exit(1);
+	    Error();
 	}
 /*
  * Read mount table entries.
@@ -180,7 +174,7 @@ no_space_for_mount:
 		(void) fprintf(stderr, " (");
 		safestrprt(mp->mnt_dir, stderr, 0);
 		(void) fprintf(stderr, ")\n");
-		Exit(1);
+		Error();
 	    }
 	    mtp->dir = dn;
 	    dn = (char *)NULL;
@@ -199,7 +193,7 @@ no_space_for_mount:
 	    {
 		(void) fprintf(stderr, "%s: no space for fstype (%s): %s\n",
 		    Pn, mtp->dir, mp->RMNT_FSTYPE);
-		Exit(1);
+		Error();
 	    }
 	    (void) strcpy(mtp->MOUNTS_FSTYPE, mp->RMNT_FSTYPE);
 # endif	/* defined(RMNT_FSTYP) && defined(MOUNTS_FSTYP) */
