@@ -30,16 +30,10 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(HASNCACHE) && defined(USE_LIB_RNAM)
 
-# if	!defined(lint)
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: rnam.c,v 1.7 98/03/24 10:40:11 abe Exp $";
-# endif	/* !defined(lint) */
-
 #include "../lsof.h"
 
 
@@ -111,7 +105,10 @@ static int Nch = 0;			/* size of name cache hash pointer
 					 * table */
 struct l_nch {
 	KA_T na;			/* node address */
+
+# if	defined(NCACHE_NODEID)
 	unsigned long id;		/* capability ID */
+# endif	/* defined(NCACHE_NODEID) */
 
 # if	defined(NCACHE_PARADDR) && defined(NCACHE_PARID)
 	KA_T pa;			/* parent node address */
@@ -128,13 +125,18 @@ static struct l_nch *Ncache = (struct l_nch*)NULL;
 static struct l_nch **Nchash = (struct l_nch **)NULL;
 					/* Ncache hash pointers */
 static int Ncfirst = 1;			/* first-call status */
-	
+
+# if	defined(NCACHE_NODEID)
 #define ncachehash(i,n)		Nchash+(((((int)(n)>>2)+((int)(i)))*31415)&Mch)
+_PROTOTYPE(static struct l_nch *ncache_addr,(unsigned long i, KA_T na));
+# else	/* !defined(NCACHE_NODEID) */
+#define ncachehash(n)		Nchash+((((int)(n)>>2)*31415)&Mch)
+_PROTOTYPE(static struct l_nch *ncache_addr,(KA_T na));
+# endif	/* defined(NCACHE_NODEID) */
+
 #define DEFNCACHESZ	1024	/* local size if X_NCSIZE kernel value < 1 */
 #define	LNCHINCRSZ	64	/* local size increment */
 
-_PROTOTYPE(static struct l_nch *ncache_addr,(unsigned long i, KA_T na));
-
 # if	!defined(NCACHE_NO_ROOT)
 _PROTOTYPE(static int ncache_isroot,(KA_T na, char *cp));
 # endif	/* !defined(NCACHE_NO_ROOT) */
@@ -145,14 +147,32 @@ _PROTOTYPE(static int ncache_isroot,(KA_T na, char *cp));
  */
 
 static struct l_nch *
+
+# if	defined(NCACHE_NODEID)
 ncache_addr(i, na)
 	unsigned long i;		/* node's capability ID */
+# else	/* !defined(NCACHE_NODEID) */
+ncache_addr(na)
+# endif	/* defined(NCACHE_NODEID) */
+
 	KA_T na;			/* node's address */
 {
 	struct l_nch **hp;
 
-	for (hp = ncachehash(i, na); *hp; hp++) {
+# if	defined(NCACHE_NODEID)
+	for (hp = ncachehash(i, na); *hp; hp++)
+# else	/* !defined(NCACHE_NODEID) */
+	for (hp = ncachehash(na); *hp; hp++)
+# endif	/* defined(NCACHE_NODEID) */
+
+	{
+
+# if	defined(NCACHE_NODEID)
 	    if ((*hp)->id == i && (*hp)->na == na)
+# else	/* !defined(NCACHE_NODEID) */
+	    if ((*hp)->na == na)
+# endif	/* defined(NCACHE_NODEID) */
+
 		return(*hp);
 	}
 	return((struct l_nch *)NULL);
@@ -238,7 +258,7 @@ ncache_isroot(na, cp)
 	    if (!nc) {
 		(void) fprintf(stderr, "%s: no space for root node table\n",
 		    Pn);
-		Exit(1);
+		Error();
 	    }
 	    nca += 10;
 	}
@@ -288,7 +308,7 @@ ncache_load()
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 			"%s: WARNING: can't read name cache size: %s\n",
-			Pn, print_kptr(v, (char *)NULL));
+			Pn, print_kptr(v, (char *)NULL, 0));
 		iNc = Nc = 0;
 		return;
 	    }
@@ -312,7 +332,7 @@ ncache_load()
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 			"%s: WARNING: can't read name cache address: %s\n",
-			Pn, print_kptr(v, (char *)NULL));
+			Pn, print_kptr(v, (char *)NULL, 0));
 		iNc = Nc = 0;
 		return;
 	    }
@@ -329,7 +349,7 @@ ncache_load()
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 			"%s: can't allocate name cache space: %d\n", Pn, len);
-		Exit(1);
+		Error();
 	    }
 # endif	/* defined(NCACHE_NXT) */
 
@@ -344,7 +364,7 @@ no_local_space:
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 			"%s: no space for %d byte local name cache\n", Pn, len);
-		Exit(1);
+		Error();
 	    }
 	} else {
 
@@ -373,7 +393,7 @@ no_local_space:
 	    if (!Fwarn)
 		(void) fprintf(stderr,
 		    "%s: WARNING: can't read kernel's name cache: %s\n",
-		    Pn, print_kptr(kp, (char *)NULL));
+		    Pn, print_kptr(kp, (char *)NULL, 0));
 	    Nc = 0;
 	    return;
         }
@@ -416,14 +436,16 @@ no_local_space:
 		    (void) fprintf(stderr,
 			"%s: no more space for %d entry local name cache\n",
 			Pn, Nc);
-		    Exit(1);
+		    Error();
 		}
 		lc = &Ncache[n];
 	    }
 # endif	/* defined(NCACHE_NXT) */
 
+#  if	defined(NCACHE_NODEID)
 	    lc->na = (KA_T)kc->NCACHE_NODEADDR;
 	    lc->id = kc->NCACHE_NODEID;
+#  endif	/* defined(NCACHE_NODEID) */
 
 #  if	defined(NCACHE_PARADDR)
 	    lc->pa = (KA_T)kc->NCACHE_PARADDR;
@@ -492,11 +514,24 @@ no_local_space:
 		(void) fprintf(stderr,
 		    "%s: no space for %d name cache hash pointers\n",
 		    Pn, Nch + Nc);
-	    Exit(1);
+	    Error();
 	}
 	for (i = 0, lc = Ncache; i < Nc; i++, lc++) {
-	    for (hp = ncachehash(lc->id, lc->na), n = 1; *hp; hp++) {
+
+# if	defined(NCACHE_NODEID)
+	    for (hp = ncachehash(lc->id, lc->na), n = 1; *hp; hp++)
+# else	/* defined(NCACHE_NODEID) */
+	    for (hp = ncachehash(lc->na), n = 1; *hp; hp++)
+# endif	/* defined(NCACHE_NODEID) */
+
+	    {
+
+# if	defined(NCACHE_NODEID)
 		if ((*hp)->na == lc->na && (*hp)->id == lc->id
+# else	/* defined(NCACHE_NODEID) */
+		if ((*hp)->na == lc->na
+# endif	/* defined(NCACHE_NODEID) */
+
 		&&  strcmp((*hp)->nm, lc->nm) == 0
 
 # if	defined(NCACHE_PARADDR) && defined(NCACHE_PARID)
@@ -550,14 +585,22 @@ ncache_lookup(buf, blen, fp)
  * file system mount point, return an empty path reply.  That tells the
  * caller to print the file system mount point name only.
  */
-	if (Lf->inp_ty == 1 && Lf->fs_ino && Lf->inode == Lf->fs_ino)
+	if ((Lf->inp_ty == 1) && Lf->fs_ino && (Lf->inode == Lf->fs_ino))
 	    return(cp);
 # endif	/* defined(HASFSINO) */
 
 /*
  * Look up the name cache entry for the node address.
  */
-	if (Nc == 0 || !(lc = ncache_addr(Lf->id, Lf->na))) {
+
+# if	defined(NCACHE_NODEID)
+	if (Nc == 0 || !(lc = ncache_addr(Lf->id, Lf->na)))
+# else	/* defined(NCACHE_NODEID) */
+	if (Nc == 0 || !(lc = ncache_addr(Lf->na)))
+# endif	/* defined(NCACHE_NODEID) */
+
+
+	{
 
 	/*
 	 * If the node has no cache entry, see if it's the mount
@@ -569,7 +612,7 @@ ncache_lookup(buf, blen, fp)
 		if (!mtp->dir || !mtp->inode)
 		    continue;
 		if (Lf->dev == mtp->dev
-		&&  (unsigned long)mtp->inode == Lf->inode
+		&&  mtp->inode == Lf->inode
 		&&  strcmp(mtp->dir, Lf->fsdir) == 0)
 		    return(cp);
 	    }
@@ -616,5 +659,5 @@ ncache_lookup(buf, blen, fp)
 	return(cp);
 }
 #else	/* !defined(HASNCACHE) || !defined(USE_LIB_RNAM) */
-static char d1[] = "d"; static char *d2 = d1;
+char rnam_d1[] = "d"; char *rnam_d2 = rnam_d1;
 #endif	/* defined(HASNCACHE) && defined(USE_LIB_RNAM) */
