@@ -31,16 +31,10 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(HASNCACHE) && defined(USE_LIB_RNMH)
 
-# if	!defined(lint)
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: rnmh.c,v 1.11 2005/08/08 19:42:23 abe Exp $";
-# endif	/* !defined(lint) */
-
 #include "../lsof.h"
 
 
@@ -299,7 +293,7 @@ ncache_isroot(na, cp)
 	    if (!nc) {
 		(void) fprintf(stderr, "%s: no space for root node table\n",
 		    Pn);
-		Exit(1);
+		Error();
 	    }
 	    nca += 10;
 	}
@@ -408,7 +402,7 @@ ncache_load()
 		(void) fprintf(stderr,
 		    "%s: can't allocate %d bytes for name cache hash table\n",
 		    Pn, len);
-		Exit(1);
+		Error();
 	    }
 	    khpl = len;
 	}
@@ -442,7 +436,7 @@ ncache_load()
 		    continue;
 
 # if	defined(NCACHE_NMLEN)
-		if (!(len = c.NCACHE_NMLEN))
+		if ((len = c.NCACHE_NMLEN) < 1)
 		    continue;
 # else	/* !defined(NCACHE_NMLEN) */
 	    /*
@@ -512,7 +506,7 @@ ncache_load()
 			(void) fprintf(stderr,
 			    "%s: can't allocate %d local name cache bytes\n",
 			    Pn, nlcl);
-			Exit(1);
+			Error();
 		    }
 		    lcl = nlcl;
 		}
@@ -605,7 +599,7 @@ ncache_load()
 		(void) fprintf(stderr,
 		    "%s: no space for %d local name cache hash pointers\n",
 		    Pn, len);
-	    Exit(1);
+	    Error();
 	}
 	for (lc = Ncache; lc; lc = lc->next) {
 
@@ -739,5 +733,5 @@ ncache_lookup(buf, blen, fp)
 	return(cp);
 }
 #else	/* !defined(HASNCACHE) || !defined(USE_LIB_RNMH) */
-static char d1[] = "d"; static char *d2 = d1;
+char rnmh_d1[] = "d"; char *rnmh_d2 = rnmh_d1;
 #endif	/* defined(HASNCACHE) && defined(USE_LIB_RNMH) */
