@@ -32,11 +32,6 @@
  * 4. This notice may not be removed or altered.
  */
 
-#ifndef lint
-static char copyright[] =
-"@(#) Copyright 2002 Purdue Research Foundation.\nAll rights reserved.\n";
-#endif
-
 #include "LsofTest.h"
 #include "lsof_fields.h"
 
@@ -396,7 +391,17 @@ print_file_error:
  */
     if (tstr || tstR || tstw || tstW) {
 	tcp = (char *)NULL;
+#if	defined(LT_DIAL_freebsd)
+	(void) PrtMsg(
+	    "Hint: lsof is unable to get the lock status when running as non-root",
+	    Pn);
+	(void) PrtMsg(
+	    "in certain FreeBSD releases (e.g. FreeBSD 13.1), thus skipping the test",
+	    Pn);
+	xv = 77;
+#else
 	xv = 1;
+#endif
     } else {
 	tcp = "OK";
 	xv = 0;
@@ -424,7 +429,7 @@ cleanup()
 }
 
 
-/* 
+/*
  * lkfile() -- lock the test file
  */
 
@@ -626,7 +631,7 @@ tstwlsof(opt, xlk)
 		    ti = -1;
 		    break;
 		}
-		ti = (ti * 10) + (int)*tcp - (int)'0'; 
+		ti = (ti * 10) + (int)*tcp - (int)'0';
 	    }
 	    if (Fd != ti)
 		break;
