@@ -32,11 +32,6 @@
  * 4. This notice may not be removed or altered.
  */
 
-#ifndef lint
-static char copyright[] =
-"@(#) Copyright 2002 Purdue Research Foundation.\nAll rights reserved.\n";
-#endif
-
 #include "LsofTest.h"
 #include "lsof_fields.h"
 
@@ -97,6 +92,15 @@ static char copyright[] =
 # endif	/* LT_VERS>=1123 && defined(__GNUC__) */
 #endif	/* defined(LT_DIAL_hpux) */
 
+#if	defined(LT_DIAL_linux)
+/*
+ * Linux-specific items
+ */
+
+#undef	LT_SOCKLEN_T
+#define	LT_SOCKLEN_T	socklen_t
+#endif	/* defined(LT_DIAL_linux) */
+
 
 #if	defined(LT_DIAL_ou)
 /*
