@@ -340,7 +340,7 @@ usage(err, fh, version)
 	    (void) fprintf(stderr, " latest FAQ: %s\n", LSOF_FAQ_URL);
 	    (void) fprintf(stderr, " latest (non-formatted) man page: %s\n", LSOF_MAN_URL);
 	    (void) fprintf(stderr,
-		" usage: [-?ab%sh%slnNoOP%s%stUvV%s]",
+		" usage: [-?ab%shH%slnNoOP%s%stUvV%s]",
 
 #if	defined(HASNCACHE)
 		"C",
@@ -602,6 +602,8 @@ usage(err, fh, version)
 	    col = print_in_col(col, "-Z Z  context [Z]");
 #endif	/* defined(HASSELINUX) */
 
+	    col = print_in_col(col, "-H human readable size");
+
 	    col = print_in_col(col, "-- end option scan");
 	    if (col != 1)
 		(void) fprintf(stderr, "\n");
@@ -982,6 +984,9 @@ usage(err, fh, version)
 #ifdef HASNULLFS
 		"nullfs",
 #endif
+#ifdef HAS_SYS_PIPEH
+		"pipe",
+#endif
 #ifdef HASPROCFS
 		"procfs",
 #endif
@@ -991,6 +996,12 @@ usage(err, fh, version)
 #ifdef HASPTYEPT
 		"ptyept",
 #endif
+#ifdef HASPTYFS
+		"ptyfs",
+#endif
+#if !defined(HASNORPC_H)
+		"rpc",
+#endif
 #ifdef HASSBSTATE
 		"sbstate",
 #endif
@@ -1006,7 +1017,7 @@ usage(err, fh, version)
 #ifdef HASTASKS
 		"tasks",
 #endif
-#ifdef HAS_TMPFS
+#if defined(HAS_TMPFS) || defined(HASTMPFS)
 		"tmpfs",
 #endif
 #ifdef HAS_XTCPCB_TMAXSEG
